@@ -23,8 +23,6 @@
 
 #include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
-#include <gtkmm.h>
-
 #include <libglom/document/view.h>
 #include <libglom/connectionpool.h>
 #include <libglom/appstate.h>
@@ -35,6 +33,7 @@
 #include <libglom/calcinprogress.h>
 #include <libglom/document/bakery/view/view.h>
 #include <glom/bakery/busy_cursor.h>
+#include <gtkmm/treemodel.h>
 
 #include <libgdamm/set.h>
 #include <libgdamm/sqlbuilder.h>
@@ -70,8 +69,6 @@ public:
   virtual void set_document(Document* pDocument); //View override
   virtual void load_from_document(); //View override
 
-  static int count_rows_returned_by(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& sql_query);
-
   sharedptr<Field> change_column(const Glib::ustring& table_name, const sharedptr<const Field>& field_old, const sharedptr<const Field>& field, Gtk::Window* parent_window) const;
 
   typedef std::vector< sharedptr<Field> > type_vec_fields;
