@@ -46,7 +46,7 @@ class Dialog_ExistingOrNew
   : public Gtk::Dialog
 {
 public:
-  static const char* glade_id;
+  static const char glade_id[];
   static const bool glade_developer;
 
   enum Action {
@@ -76,7 +76,7 @@ private:
   void existing_icon_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter);
   void existing_title_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter);
 
-  void on_switch_page(GtkNotebookPage* page, guint page_num);
+  void on_switch_page(Gtk::Widget* page, guint page_num);
   void on_existing_selection_changed();
 
 
@@ -95,10 +95,8 @@ private:
 
   
   bool list_examples_at_path(const std::string& path);
-  void on_enumerate_children(const Glib::RefPtr<Gio::AsyncResult>& res);
-  void on_next_files(const Glib::RefPtr<Gio::AsyncResult>& res);
-  void on_read(const Glib::RefPtr<Gio::AsyncResult>& res);
-  void on_stream_read(const Glib::RefPtr<Gio::AsyncResult>& res);
+  Glib::ustring get_title_from_example(const Glib::RefPtr<Gio::FileInfo>& info, const Glib::RefPtr<Gio::File>& examples_dir);
+  void append_example(const Glib::ustring& title, const Glib::RefPtr<Gio::File>& file);
 #endif /* !GLOM_ENABLE_CLIENT_ONLY */
     
 #ifndef G_OS_WIN32
@@ -197,11 +195,6 @@ private:
 
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  Glib::RefPtr<Gio::File> m_examples_dir;
-  Glib::RefPtr<Gio::FileEnumerator> m_examples_enumerator;
-  Glib::RefPtr<Gio::File> m_current_example;
-  Glib::RefPtr<Gio::InputStream> m_current_stream;
-    
   struct buffer { static const guint SIZE = 1024; char buf[SIZE]; };
   std::auto_ptr<buffer> m_current_buffer;
 #endif /* !GLOM_ENABLE_CLIENT_ONLY */
@@ -216,5 +209,5 @@ private:
 
 } //namespace Glom
 
-#endif //GLOM_DIALOG_DATABASE_PREFERENCES_H
+#endif //GLOM_DIALOG_EXISTING_OR_NEW_H
 
