@@ -24,7 +24,7 @@
 #include <gtkmm/dialog.h>
 #include <gtkmm/entry.h>
 #include <libglom/data_structure/field.h>
-#include <libglademm.h>
+#include <gtkmm/builder.h>
 
 namespace Glom
 {
@@ -37,12 +37,15 @@ bool glom_show_dialog_invalid_data(Field::glom_field_type glom_type);
 class Dialog_InvalidData : public Gtk::Dialog
 {
 public:
-  Dialog_InvalidData(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  static const char glade_id[];
+  static const bool glade_developer;
+
+  Dialog_InvalidData(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_InvalidData();
 
-  /** Show appropriate example data for this field type
+  /** Show appropriate example data for this field type.
    */
-  virtual void set_example_data(Field::glom_field_type glom_type);
+  void set_example_data(Field::glom_field_type glom_type);
 
 private:
   Gtk::Label* m_label;
