@@ -27,6 +27,8 @@
 #include <libglom/data_structure/parameternamegenerator.h>
 #include <libglom/utils.h>
 #include <libgdamm/value.h>
+#include <libgdamm/metastore.h>
+#include <glibmm/timer.h>
 #include <libgda/libgda.h> // For gda_g_type_from_string
 #include <glibmm/i18n.h>
 
@@ -144,16 +146,22 @@ bool create_database(Document* document, const Glib::ustring& database_name, con
 
     bool test = add_standard_tables(document); //Add internal, hidden, tables.
     if(!test)
+    {
+      std::cerr << G_STRFUNC << ": add_standard_tables() failed." << std::endl;
       return false;
-
+    }
+    
     progress();
 
     //Create the developer group, and make this user a member of it:
     //If we got this far then the user must really have developer privileges already:
     test = add_standard_groups(document);
     if(!test)
+    {
+      std::cerr << G_STRFUNC << ": add_standard_groups() failed." << std::endl;
       return false;
-
+    }
+    
     progress();
 
     //std::cout << "debug: " << G_STRFUNC << ": Creation of standard tables and groups finished." << std::endl;
@@ -271,16 +279,8 @@ bool recreate_database_from_document(Document* document, const sigc::slot<void>&
     }
   }
 
-  progress();
-  add_standard_tables(document); //Add internal, hidden, tables.
-
-  //Create the developer group, and make this user a member of it:
-  //If we got this far then the user must really have developer privileges already:
-  progress();
-  const bool test = add_standard_groups(document);
-  if(!test)
-    return false;
-
+  //Note that create_database() has already called add_standard_tables() and add_standard_groups(document).
+  
   for(Document::type_listTableInfo::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
   {
     sharedptr<const TableInfo> table_info = *iter;
@@ -384,7 +384,12 @@ SystemPrefs get_database_preferences(Document* document)
       return result;
     else
     {
-      add_standard_tables(document);
+      const bool test = add_standard_tables(document);
+      if(!test)
+      {
+         std::cerr << G_STRFUNC << ": add_standard_tables() failed." << std::endl;
+      }
+      
       ++attempts; //Try again now that we have tried to create the table.
     }
   }
@@ -463,7 +468,7 @@ bool add_standard_tables(Document* document)
       }
       else
       {
-        g_warning("add_standard_tables(): create_table(prefs) failed.");
+        std::cerr << G_STRFUNC << ": add_standard_tables(): create_table(prefs) failed." << std::endl;
         return false;
       }
     }
@@ -507,7 +512,7 @@ bool add_standard_tables(Document* document)
       const bool test = create_table(table_info, fields);
       if(!test)
       {
-        g_warning("add_standard_tables(): create_table(autoincrements) failed.");
+        std::cerr << G_STRFUNC << ": add_standard_tables(): create_table(autoincrements) failed." << std::endl;
         return false;
       }
 
@@ -609,7 +614,7 @@ bool add_groups_from_document(Document* document)
   Glib::RefPtr<Gnome::Gda::Connection> gda_connection = get_connection();
   if(!gda_connection)
   {
-    std::cerr << "add_standard_groups(): No connection yet." << std::endl;
+    std::cerr << G_STRFUNC << ": add_standard_groups(): No connection yet." << std::endl;
   }
 
   //Get the list of groups from the database server:
@@ -653,7 +658,7 @@ bool set_table_privileges_groups_from_document(Document* document)
   Glib::RefPtr<Gnome::Gda::Connection> gda_connection = get_connection();
   if(!gda_connection)
   {
-    std::cerr << "add_standard_groups(): No connection yet." << std::endl;
+    std::cerr << G_STRFUNC << ": add_standard_groups(): No connection yet." << std::endl;
   }
 
   //Get the list of groups from the database server:
@@ -742,7 +747,7 @@ bool handle_error()
 
 void handle_error(const Glib::Exception& ex)
 {
-  std::cerr << "Internal Error (handle_error()): exception type=" << typeid(ex).name() << ", ex.what()=" << ex.what() << std::endl;
+  std::cerr << G_STRFUNC << ": Internal Error (handle_error()): exception type=" << typeid(ex).name() << ", ex.what()=" << ex.what() << std::endl;
 
   //TODO_Moved:
   //Gtk::MessageDialog dialog(Utils::bold_message(_("Internal error")), true, Gtk::MESSAGE_WARNING );
@@ -753,7 +758,7 @@ void handle_error(const Glib::Exception& ex)
 
 void handle_error(const std::exception& ex)
 {
-  std::cerr << "Internal Error (handle_error()): exception type=" << typeid(ex).name() << ", ex.what()=" << ex.what() << std::endl;
+  std::cerr << G_STRFUNC << ": Internal Error (handle_error()): exception type=" << typeid(ex).name() << ", ex.what()=" << ex.what() << std::endl;
 
  //TODO_Moved:
   //Gtk::MessageDialog dialog(Utils::bold_message(_("Internal error")), true, Gtk::MESSAGE_WARNING );
@@ -1146,7 +1151,7 @@ bool create_table(const sharedptr<const TableInfo>& table_info, const Document::
 
   if(sql_fields.empty())
   {
-    g_warning("create_table::create_table(): sql_fields is empty.");
+    std::cerr << G_STRFUNC << ": sql_fields is empty." << std::endl;
   }
 
   //Actually create the table
@@ -1160,6 +1165,7 @@ bool create_table(const sharedptr<const TableInfo>& table_info, const Document::
   }
   catch(const ExceptionConnection& ex)
   {
+    std::cerr << G_STRFUNC << "CREATE TABLE failed: " << ex.what() << std::endl;
     table_creation_succeeded = false;
   }
 
@@ -1627,7 +1633,17 @@ bool query_execute_string(const Glib::ustring& strQuery, const Glib::RefPtr<Gnom
     std::cerr << "  full_query: " << full_query << std::endl;
     return false;
   }
-  return (exec_retval >= 0);
+  
+  //Note that only -1 means an error, not all negative values.
+  //For instance, it can return -2 for a successful CREATE TABLE query, to mean that the backend (SQLite) does not report how many rows were affected.
+  if(exec_retval == -1)
+  {
+    const Glib::ustring full_query = stmt->to_sql(params);
+    std::cerr << G_STRFUNC << "Gnome::Gda::Connection::statement_execute_non_select() failed with SQL: " << full_query << std::endl;
+    return false;
+  }
+  
+  return true;
 }
 
 bool query_execute(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& builder)
@@ -1798,6 +1814,42 @@ Glib::ustring get_unused_database_name(const Glib::ustring& base_name)
   return Glib::ustring();    
 }
 
+int count_rows_returned_by(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& sql_query)
+{
+  if(!sql_query)
+  {
+    std::cerr << G_STRFUNC << ": sql_query was null." << std::endl;
+    return 0;
+  }
+
+  const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder =
+    Utils::build_sql_select_count_rows(sql_query);
+
+  int result = 0;
+
+  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(builder);
+  if(datamodel && datamodel->get_n_rows() && datamodel->get_n_columns())
+  {
+    const Gnome::Gda::Value value = datamodel->get_value_at(0, 0);
+    //This showed me that this contains a gint64: std::cerr << "DEBUG: value type=" << G_VALUE_TYPE_NAME(value.gobj()) << std::endl;
+    //For sqlite, this is an integer
+    if(value.get_value_type() == G_TYPE_INT64) //With the PostgreSQL backend.
+      result = (int)value.get_int64();
+    else if(value.get_value_type() == G_TYPE_INT) //With the PostgreSQL backend.
+    {
+      result = value.get_int(); //With the SQLite backend.
+    }
+    else
+    {
+      std::cerr << G_STRFUNC << ": The COUNT query returned an unexpected value type: " << g_type_name(value.get_value_type()) << std::endl;
+      result = -1;
+    }
+  }
+
+  //std::cout << "debug: " << G_STRFUNC << ": Returning " << result << std::endl;
+  return result;
+}
+
 } //namespace DbUtils
 
 } //namespace Glom
