@@ -27,7 +27,7 @@
 
 #include <glibmm/i18n.h>
 
-#include <giomm.h>
+#include <giomm/file.h>
 
 #include <string.h> // for strchr
 #include <sstream> //For stringstream
@@ -194,6 +194,15 @@ Glib::ustring Utils::string_replace(const Glib::ustring& src, const Glib::ustrin
 */
 }
 
+Glib::ustring Utils::string_clean_for_xml(const Glib::ustring& src)
+{
+  // The form feed character may not be in XML, even if escaped.
+  // So lets just lose it.
+  // Other unusual characters, such as &, are escaped by libxml later.
+  // TODO_Performance: Find a quicker way to do this.
+  return string_replace(src, "\f", Glib::ustring());
+}
+
 
 Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_select_with_where_clause(const Glib::ustring& table_name, const type_vecLayoutFields& fieldsToGet, const Gnome::Gda::SqlExpr& where_clause, const sharedptr<const Relationship>& extra_join, const type_sort_clause& sort_clause, guint limit)
 {
@@ -207,6 +216,36 @@ Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_select_with_where_clause(c
   return build_sql_select_with_where_clause(table_name, constFieldsToGet, where_clause, extra_join, sort_clause, limit);
 }
 
+/** Build a SQL query to discover how many rows a SQL query would return if it was run.
+ *
+ * This uses a COUNT * on a the @a sql_query as a sub-statement.
+ * Be careful not to include ORDER BY clauses in the supplied SQL query, because that would make it unnecessarily slow.
+ *
+ * @sql_query A SQL query.
+ * @result The number of rows.
+ */
+Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_select_count_rows(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& sql_query)
+{
+  Glib::RefPtr<Gnome::Gda::SqlBuilder> result;
+
+  if(!sql_query)
+  {
+    std::cerr << G_STRFUNC << ": sql_query was null." << std::endl;
+    return result;
+  }
+
+  result = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
+
+  //Note that the alias is just because the SQL syntax requires it - we get an error if we don't use it.
+  //Be careful not to include ORDER BY clauses in this, because that would make it unnecessarily slow:
+  const guint target_id = result->add_sub_select( sql_query->get_sql_statement() );
+  result->select_add_target_id(target_id, "glomarbitraryalias");
+
+  const Gnome::Gda::SqlBuilder::Id id_function = result->add_function("COUNT", result->add_id("*"));
+  result->add_field_value_id(id_function);
+
+  return result;
+}
 
 typedef std::list< sharedptr<const UsesRelationship> > type_list_relationships;
 
@@ -441,6 +480,12 @@ Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_select_with_key(const Glib
 
 Gnome::Gda::SqlExpr Utils::build_simple_where_expression(const Glib::ustring& table_name, const sharedptr<const Field>& key_field, const Gnome::Gda::Value& key_value)
 {
+  if(!key_field)
+  {
+    std::cerr << G_STRFUNC << ": key_field was empty" << std::endl;
+    return Gnome::Gda::SqlExpr();
+  }
+  
   Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_target(table_name);  //This might not be necessary.
   const Gnome::Gda::SqlBuilder::Id id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
@@ -1103,31 +1148,6 @@ Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const Document* document,
   }
 }
 
-
-Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_select_count_rows(const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& sql_query)
-{
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> result;
-
-  if(!sql_query)
-  {
-    std::cerr << "Base_DB::count_rows_returned_by(): sql_query was null." << std::endl;
-    return result;
-  }
-
-  result = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
-
-  //Note that the alias is just because the SQL syntax requires it - we get an error if we don't use it.
-  //Be careful not to include ORDER BY clauses in this, because that would make it unnecessarily slow:
-  const guint target_id = result->add_sub_select( sql_query->get_sql_statement() );
-  result->select_add_target_id(target_id, "glomarbitraryalias");
-
-  const Gnome::Gda::SqlBuilder::Id id_function = result->add_function("COUNT", result->add_id("*"));
-  result->add_field_value_id(id_function);
-
-  return result;
-}
-
-
 bool Utils::delete_directory(const Glib::RefPtr<Gio::File>& directory)
 {
   if(!(directory->query_exists()))
@@ -1200,6 +1220,58 @@ Glib::ustring Utils::get_directory_child_with_suffix(const Glib::ustring& uri_di
   return Glib::ustring();
 }
 
+Glib::ustring Utils::get_file_uri_without_extension(const Glib::ustring& uri)
+{
+  if(uri.empty())
+    return uri;
+
+  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
+  if(!file)
+    return uri; //Actually an error.
+
+  const Glib::ustring filename_part = file->get_basename();
+
+  const Glib::ustring::size_type pos_dot = filename_part.rfind(".");
+  if(pos_dot == Glib::ustring::npos)
+    return uri; //There was no extension, so just return the existing URI.
+  else
+  {
+    const Glib::ustring filename_part_without_ext = filename_part.substr(0, pos_dot);
+
+    //Use the Gio::File API to manipulate the URI:
+    Glib::RefPtr<Gio::File> parent = file->get_parent();
+    Glib::RefPtr<Gio::File> file_without_extension = parent->get_child(filename_part_without_ext);
+
+    return file_without_extension->get_uri();
+  }
+}
+
+std::string Utils::get_file_path_without_extension(const std::string& filepath)
+{
+  if(filepath.empty())
+    return filepath;
+
+  Glib::RefPtr<Gio::File> file = Gio::File::create_for_path(filepath);
+  if(!file)
+    return filepath; //Actually an error.
+
+  const Glib::ustring filename_part = file->get_basename();
+
+  const Glib::ustring::size_type pos_dot = filename_part.rfind(".");
+  if(pos_dot == Glib::ustring::npos)
+    return filepath; //There was no extension, so just return the existing URI.
+  else
+  {
+    const Glib::ustring filename_part_without_ext = filename_part.substr(0, pos_dot);
+
+    //Use the Gio::File API to manipulate the URI:
+    Glib::RefPtr<Gio::File> parent = file->get_parent();
+    Glib::RefPtr<Gio::File> file_without_extension = parent->get_child(filename_part_without_ext);
+
+    return file_without_extension->get_path();
+  }
+}
+
 Glib::ustring Utils::get_list_of_layout_items_for_display(const LayoutGroup::type_list_items& list_layout_fields)
 {
   Glib::ustring result;
