@@ -29,10 +29,11 @@
 #include <glom/glade_utils.h>
 #include <glom/utils_ui.h>
 #include <libglom/privs.h>
-#include <glom/xsl_utils.h>
 #include <glom/python_embed/glom_python.h>
 #include <glom/print_layout/print_layout_utils.h>
 #include <glom/application.h>
+#include <gtkmm/stock.h>
+#include <gtkmm/viewport.h>
 #include <sstream> //For stringstream
 #include <glibmm/i18n.h>
 
@@ -910,7 +911,7 @@ sharedptr<Field> Box_Data_Details::get_field_primary_key() const
 
 void Box_Data_Details::print_layout()
 {
- const Privileges table_privs = Privs::get_current_privs(m_table_name);
+  const Privileges table_privs = Privs::get_current_privs(m_table_name);
 
   //Don't try to print tables that the user can't view.
   if(!table_privs.m_view)
@@ -929,14 +930,19 @@ void Box_Data_Details::print_layout()
     std::cerr << G_STRFUNC << ": page_setup was null" << std::endl;
     return;
   }
-  
+
+  //Note that we initially create the page layout without spaces for page 
+  //breaks because those spaces would be empty space on the page after
+  //we have moved items down when expanding:
+  //TODO: Squash that space when expanding custom layouts.
   sharedptr<PrintLayout> print_layout = 
-    PrintLayoutUtils::create_standard(page_setup, m_table_name, document);
+    PrintLayoutUtils::create_standard(page_setup, m_table_name, document,
+      false /* do not avoid page margins */);
   
   //Show the print preview window:
   Application* app = Application::get_application();
   PrintLayoutUtils::do_print_layout(print_layout, m_found_set,
-    true /* not preview */, document, app);  
+    false /* not preview */, document, true /* avoid page margins */, app);
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
