@@ -30,7 +30,7 @@ namespace Glom
 
 class Box_Data_List_Related : public Box_Data_Portal
 {
-public: 
+public:
   Box_Data_List_Related();
 
   /**
@@ -42,6 +42,8 @@ public:
    */
   virtual bool init_db_details(const Glib::ustring& parent_table, bool show_title = true);
 
+  virtual void set_find_mode(bool val = true);
+
 protected:
   virtual bool fill_from_database(); //Override.
 
@@ -55,34 +57,33 @@ protected:
   bool on_script_button_idle(const sharedptr<const LayoutItem_Button>& layout_item, const Gnome::Gda::Value& primary_key);
 
   void on_adddel_record_added(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& primary_key_value);
-    
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_adddel_user_requested_layout();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
-    
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual void on_dialog_layout_hide(); //override.
-#endif // !GLOM_ENABLE_CLIENT_ONLY 
-  
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
   //Implementations of pure virtual methods from Base_DB_Table_Data:
   virtual sharedptr<Field> get_field_primary_key() const; //TODO: Already in base class?
   virtual Gnome::Gda::Value get_primary_key_value_selected() const;
   virtual void set_primary_key_value(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& value);
   virtual Gnome::Gda::Value get_primary_key_value(const Gtk::TreeModel::iterator& row) const;
- 
+
   //Overrides of functions from Box_Data:
-  virtual void create_layout(); //override
   virtual Document::type_list_layout_groups create_layout_get_layout();
-  void create_layout_add_group(const sharedptr<LayoutGroup>& layout_group);
-    
+  virtual void create_layout();
+
   virtual void enable_buttons(); //override
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual Dialog_Layout* create_layout_dialog() const; // override.
   virtual void prepare_layout_dialog(Dialog_Layout* dialog); // override.
 #endif // !GLOM_ENABLE_CLIENT_ONLY
-    
-    
+
+
   //Member widgets:
   mutable DbAddDel_WithButtons m_AddDel; //mutable because its get_ methods aren't const.
 };
