@@ -26,6 +26,12 @@
 #include <libglom/data_structure/glomconversions.h>
 #include <glom/utility_widgets/dialog_image_load_progress.h>
 #include <glom/utility_widgets/dialog_image_save_progress.h>
+#include <gtkmm/appchooserdialog.h>
+#include <gtkmm/filechooserdialog.h>
+#include <gtkmm/stock.h>
+#include <giomm/file.h>
+#include <giomm/contenttype.h>
+#include <glibmm/convert.h>
 
 #include <iostream>   // for cout, endl
 
@@ -98,7 +104,7 @@ void ImageGlom::set_layout_item(const sharedptr<LayoutItem>& layout_item, const
 bool ImageGlom::on_button_press_event(GdkEventButton *event)
 {
   GdkModifierType mods;
-  gdk_window_get_pointer( gtk_widget_get_window (Gtk::Widget::gobj()), 0, 0, &mods );
+  gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), event->device, 0, 0, &mods );
 
   //Enable/Disable items.
   //We did this earlier, but get_application is more likely to work now:
